@@ -299,16 +299,22 @@ _folder_label_clicked_cb (GtkLabel *label, const gchar *uri, gpointer user_data)
 {
 	EogMetadataSidebarPrivate *priv = EOG_METADATA_SIDEBAR(user_data)->priv;
 	EogImage *img;
-	GdkScreen *screen;
+	GtkWidget *toplevel;
+	GtkWindow *window;
 	GFile *file;
 
 	g_return_if_fail (priv->parent_window != NULL);
 
 	img = eog_window_get_image (priv->parent_window);
-	screen = gtk_widget_get_screen (GTK_WIDGET (priv->parent_window));
 	file = eog_image_get_file (img);
 
-	eog_util_show_file_in_filemanager (file, screen);
+	toplevel = gtk_widget_get_toplevel (GTK_WIDGET (label));
+	if (GTK_IS_WINDOW (toplevel))
+		window = GTK_WINDOW (toplevel);
+	else
+		window = NULL;
+
+	eog_util_show_file_in_filemanager (file, window);
 
 	g_object_unref (file);
 }
@@ -490,7 +496,6 @@ eog_metadata_sidebar_new (EogWindow *window)
 			       "vadjustment", NULL,
 			       "hscrollbar-policy", GTK_POLICY_NEVER,
 			       "vscrollbar-policy", GTK_POLICY_AUTOMATIC,
-			       "border-width", 6,
 			       "parent-window", window,
 			       NULL);
 }
